
.. code:: robotframework

    *** Test Cases ***
    First testcase
        No Operation

    Second testcase
        No Operation


.. code:: robotframework

    *** Test Cases ***
    Test case with allure id
        [Tags]  allure.id=123
        No Operation

    One more case with allure id
        [Tags]  allure.id=777
        No Operation
